# zzpy
Python3 Utilities
```shell
# pip3 install zzpy -i https://pypi.org/simple
# pip3 install zzpy --upgrade -i https://pypi.org/simple
```


# 待验证
- [ ] zgeo


# 未完成
- [ ] zexcel
- [ ] zcaptcha
- [ ] zbrowser
- [ ] zjson
- [ ] zrun
- [ ] ztime


# 已完成
- [x] zrandom
- [x] zconfig
- [x] zfile
- [x] zmongo
- [x] zmysql
- [x] zredis
- [x] zsys


# release log
* 1.0.20200812.5: zalioss修复默认配置的bug
* 1.0.20200812.4: +zalioss
* 1.0.20200812.3: zjson.jsondumps cls参数默认值为DateEncoder
* 1.0.20200812.2: zmysql.mysql_iter_table fix default parameters
* 1.0.20200812.1: zmysql.mysql_iter_table+fields
* 1.0.20200812: zmysql+mysql_iter_table
* 1.0.20200723: zmysql.MySQLConfig对MYSQL_URL解析规则问题修复
* 1.0.20200721: ztime+get_month
* 1.0.9: build.sh
* 1.0.8: +get_today, +get_date
* 1.0.7: jsondumps+params
* 1.0.6: +jsondumps

